summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutSize.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficeui/KoPageLayoutSize.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficeui/KoPageLayoutSize.h')
-rw-r--r--lib/kofficeui/KoPageLayoutSize.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/lib/kofficeui/KoPageLayoutSize.h b/lib/kofficeui/KoPageLayoutSize.h
index ebdf49b6..aa5f23bd 100644
--- a/lib/kofficeui/KoPageLayoutSize.h
+++ b/lib/kofficeui/KoPageLayoutSize.h
@@ -17,37 +17,38 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef kopagelayoutsize_h
-#define kopagelayoutsize_h
+#ifndef kopagetqlayoutsize_h
+#define kopagetqlayoutsize_h
-#include <qgroupbox.h>
+#include <tqgroupbox.h>
#include <KoGlobal.h>
#include <KoUnit.h>
#include <kdialogbase.h>
#include <KoPageLayout.h>
#include <KoPageLayoutDia.h>
-class QComboBox;
+class TQComboBox;
class KoUnitDoubleSpinBox;
class KoPageLayoutColumns;
/**
* This class is a widget that shows the KoPageLayout data structure and allows the user to change it.
*/
-class KoPageLayoutSize : public QWidget {
+class KoPageLayoutSize : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Contructor
* @param parent the parent widget
* @param layout the page layout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
* @param unitChooser if true a combobox with the unit-type is shown for the user to change
* @param enableBorders if true enable the user to change the margins (aka borders) of the page
*/
- KoPageLayoutSize(QWidget *parent, const KoPageLayout& layout, KoUnit::Unit unit,
+ KoPageLayoutSize(TQWidget *tqparent, const KoPageLayout& tqlayout, KoUnit::Unit unit,
const KoColumns& columns, bool unitChooser, bool enableBorders);
/**
@@ -77,14 +78,14 @@ public slots:
signals:
/**
* Emitted whenever the user changed something in the dialog.
* @param layout the update layout structure with currently displayed info.
* Note that the info may not be fully correct and physically possible (in which
* case queryClose will return false)
*/
- void propertyChange(KoPageLayout &layout);
+ void propertyChange(KoPageLayout &tqlayout);
protected:
- QComboBox *cpgFormat;
+ TQComboBox *cpgFormat;
KoUnitDoubleSpinBox *epgWidth;
KoUnitDoubleSpinBox *epgHeight;
KoUnitDoubleSpinBox *ebrLeft;
@@ -92,7 +93,7 @@ protected:
KoUnitDoubleSpinBox *ebrTop;
KoUnitDoubleSpinBox *ebrBottom;
KoPagePreview *pgPreview;
- QButtonGroup *m_orientGroup;
+ TQButtonGroup *m_orientGroup;
protected slots:
void formatChanged( int );
@@ -17,37 +17,38 @@
/**
* Contructor
- * @param parent the parent widget
- * @param layout the page layout that this widget should be initialzed with.
+ * @param tqparent the tqparent widget
+ * @param tqlayout the page tqlayout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
@@ -77,14 +78,14 @@ public slots:
/**
* Emitted whenever the user changed something in the dialog.
- * @param layout the update layout structure with currently displayed info.
+ * @param tqlayout the update tqlayout structure with currently displayed info.
* Note that the info may not be fully correct and physically possible (in which
* case queryClose will return false)